@@ -17,6 +17,7 @@
 
 """Adviser test suite."""
 
+import pandas as pd
 from tests.base_test import ReportProcessingTestCase
 
 from thoth.report_processing.components.adviser import Adviser
@@ -32,58 +33,58 @@ class TestAdviser(ReportProcessingTestCase):
         adviser_files = Adviser.aggregate_adviser_results(repo_path=self._ADVISER_FOLDER_PATH, is_local=True)
         assert adviser_files
 
-    def test_create_adviser_dataframe_with_no_results(self) -> None:
-        """Test create of adviser dataframe from adviser documents with no results."""
-        adviser_files = Adviser.aggregate_adviser_results(repo_path=self._ADVISER_FOLDER_PATH, is_local=True)
-
-        adviser_version = "0.10.0"
-        adviser_dataframe = Adviser.create_adviser_dataframe(
-            adviser_version=adviser_version, adviser_files=adviser_files
-        )
-
-        assert adviser_dataframe.empty
-
     def test_create_adviser_dataframe_with_results(self) -> None:
         """Test create of adviser dataframe from adviser documents."""
         adviser_files = Adviser.aggregate_adviser_results(repo_path=self._ADVISER_FOLDER_PATH, is_local=True)
 
-        adviser_version = "0.9.3"
-        adviser_dataframe = Adviser.create_adviser_dataframe(
-            adviser_version=adviser_version, adviser_files=adviser_files
+        adviser_version = "0.21.1"
+        justifications_collected = []
+        justifications_collected = Adviser.create_adviser_dataframe(
+            adviser_version=adviser_version,
+            adviser_files=adviser_files,
+            justifications_collected=justifications_collected,
         )
 
-        assert adviser_dataframe.shape[0] == 2
+        adviser_dataframe = pd.DataFrame(justifications_collected)
+
+        assert adviser_dataframe.shape[0] == 3
 
     def test_create_adviser_dataframe_histogram(self) -> None:
         """Test create of adviser dataframe for histogram plot from adviser documents."""
         adviser_files = Adviser.aggregate_adviser_results(repo_path=self._ADVISER_FOLDER_PATH, is_local=True)
 
-        adviser_version = "0.9.3"
-        adviser_dataframe = Adviser.create_adviser_dataframe(
-            adviser_version=adviser_version, adviser_files=adviser_files
+        adviser_version = "0.21.1"
+        justifications_collected = []
+        justifications_collected = Adviser.create_adviser_dataframe(
+            adviser_version=adviser_version,
+            adviser_files=adviser_files,
+            justifications_collected=justifications_collected,
         )
 
-        final_dataframe = Adviser.create_summary_dataframe(adviser_dataframe=adviser_dataframe)
+        adviser_dataframe = pd.DataFrame(justifications_collected)
 
         sorted_justifications_df = Adviser.create_adviser_results_dataframe_histogram(
-            adviser_type_dataframe=final_dataframe
+            adviser_type_dataframe=adviser_dataframe
         )
 
-        assert sorted_justifications_df.shape[0] == 2
+        assert sorted_justifications_df.shape[0] == 3
 
     def test_create_adviser_dataframe_heatmap(self) -> None:
         """Test create of adviser dataframe for heatmap plot from adviser documents."""
         adviser_files = Adviser.aggregate_adviser_results(repo_path=self._ADVISER_FOLDER_PATH, is_local=True)
 
-        adviser_version = "0.9.3"
-        adviser_dataframe = Adviser.create_adviser_dataframe(
-            adviser_version=adviser_version, adviser_files=adviser_files
+        adviser_version = "0.21.1"
+        justifications_collected = []
+        justifications_collected = Adviser.create_adviser_dataframe(
+            adviser_version=adviser_version,
+            adviser_files=adviser_files,
+            justifications_collected=justifications_collected,
         )
 
-        final_dataframe = Adviser.create_summary_dataframe(adviser_dataframe=adviser_dataframe)
+        adviser_dataframe = pd.DataFrame(justifications_collected)
 
         adviser_heatmap_df = Adviser.create_adviser_results_dataframe_heatmap(
-            adviser_type_dataframe=final_dataframe, number_days=1
+            adviser_type_dataframe=adviser_dataframe, number_days=1
         )
 
         last_date = [column for column in adviser_heatmap_df.columns][-1]
